@@ -12,13 +12,13 @@ logger = logging.getLogger("envchain-python")
 # --- Serialization/Deserialization ---
 
 
-def serialize_object_to_string(data: dict) -> str:
+def serialize_object_to_string(data: dict | list) -> str:
     """
-    Serializes a Python dictionary (ideally with standard scalar types, lists,
+    Serializes a Python dictionary or list (ideally with standard scalar types, lists,
     and nested dictionaries) to a compact, single-line JSON string.
 
     Args:
-        data: The dictionary to serialize.
+        data: The dictionary or list to serialize.
 
     Returns:
         A single-line JSON string representation of the data.
@@ -26,14 +26,14 @@ def serialize_object_to_string(data: dict) -> str:
     Raises:
         TypeError: If 'data' is not a dictionary.
     """
-    if not isinstance(data, dict):
+    if not isinstance(data, (dict, list)):
         raise TypeError("Input 'data' must be a dictionary.")
     # Using separators=(',', ':') ensures no extra whitespace and a compact string.
     # return json.dumps(data, sort_keys=True, separators=(",", ":"))
     return json.dumps(data, separators=(",", ":"))
 
 
-def deserialize_string_to_object(s: str) -> dict:
+def deserialize_string_to_object(s: str) -> dict | list:
     """
     Deserializes a JSON string (presumably created by serialize_object_to_string)
     back into a Python dictionary.
@@ -151,7 +151,6 @@ def set_vars(
     namespace: str,
     variables: dict[str, str | None],
     require_passphrase: bool = False,
-    # noecho: bool = False,
 ) -> None:
     """
     Sets variables in the specified envchain namespace.
@@ -162,7 +161,6 @@ def set_vars(
                    Values must be strings or None (which sets an empty string).
                    String values should not contain newline characters.
         require_passphrase: If True, passes --require-passphrase to envchain (macOS).
-        noecho: If True, passes --noecho to envchain to hide input values during prompting.
 
     Raises:
         ValueError: If namespace is empty, or any variable key/value is invalid.
@@ -237,7 +235,38 @@ def set_vars(
         logger.warning(f"envchain stderr (set):\n{stderr}")
 
 
-def unset_vars(namespace: str, variable_keys: list[str]) -> None:
+def set_var(namespace: str, key: str, value: str | None) -> None:
+    """
+    Sets a single variable in the specified envchain namespace.
+    This is a convenience wrapper around set_vars.
+    Args:
+        namespace: The envchain namespace.
+        key: The variable key (string) to set.
+        value: The variable value (string or None) to set.
+               If None, sets an empty string.
+    Raises:
+        ValueError: If namespace is empty or key/value is invalid.
+        TypeError: If arguments have incorrect types.
+        EnvchainError: If the envchain command fails.
+    """
+    if not isinstance(namespace, str) or not namespace.strip():
+        raise ValueError("Namespace must be a non-empty string.")
+    namespace = namespace.strip()
+
+    if not isinstance(key, str) or not key.strip():
+        raise ValueError("Key must be a non-empty string.")
+    key = key.strip()
+
+    if value is not None and not isinstance(value, str):
+        raise TypeError("Value must be a string or None.")
+
+    set_vars(namespace, {key: value})  # Use the set_vars function for setting
+    logger.info(f"Set variable '{key}' in envchain namespace '{namespace}'.")
+    # No need to return anything; set_vars handles the operation
+    return
+
+
+def unset_vars(namespace: str, variable_keys: list[str] | str) -> None:
     """
     Unsets variables in the specified envchain namespace.
 
@@ -254,6 +283,8 @@ def unset_vars(namespace: str, variable_keys: list[str]) -> None:
         raise ValueError("Namespace must be a non-empty string.")
     namespace = namespace.strip()
 
+    if isinstance(variable_keys, str):
+        variable_keys = [variable_keys]  # Convert single string to list
     if not isinstance(variable_keys, list):
         raise TypeError("variable_keys must be a list of strings.")
     if not variable_keys:
@@ -377,114 +408,27 @@ def get_vars(namespace: str, *variable_keys: str) -> dict[str, str]:
     return retrieved_vars
 
 
-def main() -> None:
-    # --- Example Usage ---
-    # Configure basic logging for demonstration if run directly
-    logging.basicConfig(
-        level=logging.DEBUG,
-        format="%(asctime)s - %(name)s - %(levelname)s - %(message)s",
-    )
-    logger.info("envchain-python library example usage:")
+def get_var(namespace: str, key: str) -> str | None:
+    """
+    Retrieves a single variable from an envchain namespace.
 
-    # --- Serialization example ---
-    my_complex_data = {
-        "api_key": "test_key_123",
-        "settings": {
-            "retries": 5,
-            "timeout": 60,
-            "feature_flags": ["new_ui", "beta_access"],
-        },
-        "user_email": "user@example.com",
-    }
+    Args:
+        namespace: The envchain namespace (string).
+        key: The variable key (string) to retrieve.
+    Returns:
+        The value of the variable (string) if found, or None if not found.
+    Raises:
+        ValueError: If namespace or key is empty.
+        TypeError: If arguments have incorrect types.
+        EnvchainError: If the envchain command fails (e.g., namespace not found).
+    """
+    if not isinstance(namespace, str) or not namespace.strip():
+        raise ValueError("Namespace must be a non-empty string.")
+    namespace = namespace.strip()
 
-    try:
-        serialized_string = serialize_object_to_string(my_complex_data)
-        print(f"\n[Serialization] Serialized data: {serialized_string}")
+    if not isinstance(key, str) or not key.strip():
+        raise ValueError("Key must be a non-empty string.")
+    key = key.strip()
 
-        deserialized_object = deserialize_string_to_object(serialized_string)
-        print(
-            f"[Serialization] Deserialized data matches original: {deserialized_object == my_complex_data}"
-        )
-    except (TypeError, json.JSONDecodeError) as e:
-        print(f"[Serialization] Error: {e}")
-
-    # --- Envchain example ---
-    # Note: These operations will interact with your actual envchain setup.
-    # Ensure `envchain` is installed and configured.
-    test_namespace = "ecp_test_app"
-    test_namespace_complex = "ecp_test_complex_cfg"
-
-    try:
-        print(f"\n--- Envchain Operations for namespace '{test_namespace}' ---")
-        # Set simple variables
-        vars_to_set = {
-            "API_USER": "python_user",
-            "API_TOKEN": "python_token_example_!@#",
-        }
-        set_vars(test_namespace, vars_to_set)  # Use noecho for tokens # type: ignore
-        print(f"Set {len(vars_to_set)} variables in '{test_namespace}'.")
-
-        # Get specific variables
-        retrieved_user = get_vars(test_namespace, "API_USER")
-        print(
-            f"Retrieved API_USER from '{test_namespace}': {retrieved_user.get('API_USER', 'NOT FOUND')}"
-        )
-
-        # Get all variables in namespace
-        all_retrieved = get_vars(test_namespace)
-        print(f"All variables retrieved from '{test_namespace}': {all_retrieved}")
-        assert all_retrieved.get("API_USER") == "python_user"
-        assert all_retrieved.get("API_TOKEN") == "python_token_example_!@#"
-
-        print(f"\n--- Envchain Operations for namespace '{test_namespace_complex}' ---")
-        # Set a variable with a serialized object
-        set_vars(test_namespace_complex, {"COMPLEX_CONFIG_JSON": serialized_string})
-        print(f"Set COMPLEX_CONFIG_JSON in '{test_namespace_complex}'.")
-
-        # Retrieve and deserialize the complex config
-        retrieved_complex_map = get_vars(test_namespace_complex, "COMPLEX_CONFIG_JSON")
-        json_val_from_envchain = retrieved_complex_map.get("COMPLEX_CONFIG_JSON")
-        if json_val_from_envchain:
-            original_data_from_envchain = deserialize_string_to_object(
-                json_val_from_envchain
-            )
-            print(
-                f"Retrieved and deserialized COMPLEX_CONFIG_JSON: {original_data_from_envchain}"
-            )
-            assert original_data_from_envchain == my_complex_data
-        else:
-            print(f"COMPLEX_CONFIG_JSON not found in '{test_namespace_complex}'.")
-
-        print("\n--- Listing Namespaces ---")
-        namespaces = list_namespaces()
-        print(f"Available envchain namespaces: {namespaces}")
-        assert test_namespace in namespaces
-        assert test_namespace_complex in namespaces
-
-    except EnvchainError as e:
-        print(f"\n[Envchain Operation] FAILED: {e}")
-        # Detailed error info is in e.stdout, e.stderr, e.returncode
-    except (ValueError, TypeError) as e:
-        print(f"\n[Input/Validation Error] FAILED: {e}")
-    finally:
-        # --- Cleanup: Unset the test variables/namespaces ---
-        print("\n--- Cleanup ---")
-        try:
-            if test_namespace in list_namespaces():  # Check if exists before unsetting
-                unset_vars(test_namespace, ["API_USER", "API_TOKEN"])
-                print(f"Cleaned up variables from '{test_namespace}'.")
-        except EnvchainError as e:
-            print(f"Error cleaning up '{test_namespace}': {e}")
-
-        try:
-            if test_namespace_complex in list_namespaces():
-                unset_vars(test_namespace_complex, ["COMPLEX_CONFIG_JSON"])
-                print(f"Cleaned up variables from '{test_namespace_complex}'.")
-        except EnvchainError as e:
-            print(f"Error cleaning up '{test_namespace_complex}': {e}")
-
-        print("\nExample run finished.")
-
-
-if __name__ == "__main__":
-    main()
+    retrieved_vars = get_vars(namespace, key)
+    return retrieved_vars.get(key)  # Returns None if key is not found
